@@ -36,6 +36,8 @@ PocoDatabase::PocoDatabase (const string& connect, bool verbose, const string& K
 	, m_verbose(verbose)
 	, m_KEY(KEY)
 	, m_pSession(NULL)
+	, m_collectionMetaInfos()
+	, m_transactionCounter(0)
 {
 	SessionFactory::instance().add(m_KEY, pConnector);
 }
@@ -136,20 +138,27 @@ char PocoDatabase::GetCollectionType (const string& name) const throw (Xception)
 }
 
 //=== DBTransactor =========================================================
-DBTransactor::DBTransactor (Poco::Data::Session* pSession)
+DBTransactor::DBTransactor (Poco::Data::Session* pSession, size_t& counter)
 	: m_pSession(pSession)
+	, m_counter(counter)
 {
-	m_pSession->begin();
+	if (++m_counter == 1 && m_pSession)
+		m_pSession->begin();
 }
 
 DBTransactor::~DBTransactor ()
 {
-	if (m_pSession)
+	if (m_counter == 1 && m_pSession)
 		m_pSession->rollback();
+
+	m_counter--;
 }
 
 void DBTransactor::Commit ()
 {
-	m_pSession->commit();
-	m_pSession = NULL;
+	if (m_counter == 1)
+	{
+		m_pSession->commit();
+		m_pSession = NULL;
+	}
 }
