@@ -281,7 +281,7 @@ void PocoDatabaseImpl::AddRejected (const ptime& timestamp, const string& expr)
 	try
 	{
 		const string& t = lexical_cast<string, ptime>(timestamp);
-		(*m_pSession) << "insert into TRejected values (null,'" << t << "','" << expr << "';", now;
+		(*m_pSession) << "insert into TRejected values (null,'" << t << "','" << expr << "');", now;
 	}
 	catch (...)
 	{
