@@ -42,8 +42,9 @@ void InputImpl::Parse (const string& expr, const ptime& timestamp, bool verbose,
 	static const regex rx_datetime("([0-9]{1,4})-([0-9]{1,2})-([0-9]{1,2})-([0-9]{1,2})[:]([0-9]{1,2})(?:[:]([0-9]{1,2}))?"); // 2009-02-27-15:27[:59]
 	static const regex rx_time("([0-9]{1,2})[:]([0-9]{1,2})(?:[:]([0-9]{1,2}))?");		// 15:27[:59]
 	static const regex rx_date("([0-9]{1,4})-([0-9]{1,2})-([0-9]{1,2})");			// 2009-02-27
+	static const regex rx_string("\"((?:[^\"]|(?:\"\"))*)\"("RX_COLLECTION_NAME")");	// "..." A-Z a-z _ * + ! ? ^   $ & [ ] { } = ~
 	static const regex rx_ratio("([0-9]+(?:\\.[0-9]+)?)([/%])([0-9]+(?:\\.[0-9]+)?)");	// double[/%]double
-	static const regex rx_numeric("([0-9]+(?:\\.[0-9]+)?)("RX_COLLECTION_NAME")?");		// double A-Z a-z _ * + ! ? ^   $ & [ ] { } = ~
+	static const regex rx_numeric("([0-9]+(?:\\.[0-9]+)?)("RX_COLLECTION_NAME")?");		// double [A-Z a-z _ * + ! ? ^   $ & [ ] { } = ~]
 
 	smatch mr;
 
@@ -135,6 +136,15 @@ void InputImpl::Parse (const string& expr, const ptime& timestamp, bool verbose,
 		line.erase(mr.position(), mr.length());
 	}
 
+	while (regex_search(line, mr, rx_string, boost::match_not_dot_newline))
+	{
+		string name(mr[2]);
+		string value(mr[1]);
+		replace_all(value, "\"\"", "\"");
+		items.insert(Database::CollectionsItems::value_type(name, Database::CollectionItem(t, value)));
+		line.erase(mr.position(), mr.length());
+	}
+
 	// last check
 	trim(line);
 	if (!line.empty())
