@@ -33,9 +33,9 @@ using namespace boost::program_options;
 #include <readline/history.h>
 #endif
 
-#include <boost/tokenizer.hpp> 
+#include <boost/tokenizer.hpp>
 
-//=== CSVFile ==============================================================
+//=== InputInteractive =====================================================
 InputInteractive::InputInteractive (const string& option_key)
 	: InputImpl(option_key)
 {
@@ -164,14 +164,14 @@ void InputInteractive::Do (const Config& config, Database& database) const throw
 				<< "q               quit pdr" << endl
 				<< endl
 				;
-			break;
+			continue;
 		}
 
 		// all other commands require a current data line, if the
 		// database is empty we just do the loop but we don't allow
 		// any further command execution
 		if (I == expressions.end())
-			break;
+			continue;
 
 		try
 		{
