@@ -28,6 +28,7 @@ using namespace boost::program_options;
 #include "../libpdrx/build.h"
 #include "db.h"
 #include "in.h"
+#include "out.h"
 
 //=== ConfigImpl ===========================================================
 class ConfigImpl: public Config {
@@ -49,6 +50,7 @@ ConfigImpl::ConfigImpl ()
 		("version,V",						"display version number and quit")
 		("verbose,v",						"produce verbose output on stdout")
 		("config,c", value<string>(),				"use specific configuration file")
+		("interactive,i",					"start interactive")
 
 		// database options
 		("list-collections,l",					"list all available collections in the database")
@@ -64,6 +66,9 @@ ConfigImpl::ConfigImpl ()
 		("csv,C", value<vector<string> >(),			"use csv file arg for database input")
 		("xml,x", value<vector<string> >(),			"use xml file arg for database input")
 		("none,n",						"don't use any configured input, just the command line")
+
+		// output options
+		("export,X", value<string>(),				"create an xml export file")
 	;
 
 	// in pdr we need a second options description for a hidden
@@ -160,6 +165,12 @@ int main (int argc, char* argv[])
 		{
 			auto_ptr<Database> database(DBFactory::Create(*config));
 
+			if (config->GetBoolOption("interactive"))
+			{
+				auto_ptr<Input>(InputFactory().GetInputInteractive())->Do(*config, *database);
+				return 0;
+			}
+
 			// list operations
 			{
 				bool abort = false;
@@ -227,8 +238,8 @@ int main (int argc, char* argv[])
 
 			// get input
 			{
-				set<string> msgs;
 				InputFactory factory;
+				set<string> msgs;
 				const InputFactory::Inputs& inputs = factory.GetInputs(*config);
 				foreach (const Input* pInput, inputs)
 				{
@@ -253,6 +264,16 @@ int main (int argc, char* argv[])
 					throw Xarning(s);
 				}
 			}
+
+			// produce output
+			{
+				OutputFactory factory;
+				const OutputFactory::Outputs& outputs = factory.GetOutputs(*config);
+				foreach (const Output* pOutput, outputs)
+				{
+					pOutput->Do(*config, *database);
+				}
+			}
 		}
 
 		return 0;
