@@ -43,13 +43,13 @@ DiagramSVG::DiagramSVG ()
 {
 	m_diagram.width = m_diagram.height = 0.0;
 
-#ifdef _BOARD_PATH_H_
+//#ifdef _BOARD_PATH_H_
 	// libboard 0.9.0
-	m_canvas.setUnit(Board::UPoint);
-#else
+//	m_canvas.setUnit(Board::UPoint);
+//#else
 	// libboard 0.8.8
 	m_canvas.setUnit(Board::PT);
-#endif
+//#endif
 }
 
 void DiagramSVG::OpenCanvas (size_t width, size_t height, RGB bgColor)
